<?php
/**
 * Database configuration using Eloquent ORM.
 *
 * @package ServiceEZ
 * @subpackage Database
 * @since 1.0.0
 */

namespace ServiceEZ\Database\Migrations;

use ServiceEZ\Interfaces\Migration;
use Prappo\WpEloquent\Database\Capsule\Manager as Capsule;
use Prappo\WpEloquent\Support\Facades\Schema;

/**
 * Clients migration class.
 *
 * @package ServiceEZ
 * @subpackage Database
 * @since 1.0.0
 */
class Clients implements Migration {
	/**
	 * Up method.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function up() {
		if ( Capsule::schema()->hasTable( 'serviceez_clients' ) ) {
			return;
		}
		Schema::create(
			'serviceez_clients',
			function ( $table ) {
				$table->id();
				$table->unsignedBigInteger( 'user_id' );
				$table->string( 'firstName' );
				$table->string( 'lastName' );
				$table->string( 'email' )->unique();
				$table->string( 'phone' )->nullable();
				$table->string( 'address_line1' )->nullable();
				$table->string( 'address_line2' )->nullable();
				$table->string( 'city' )->nullable();
				$table->string( 'state' )->nullable();
				$table->string( 'postal_code' )->nullable();
				$table->string( 'country' )->nullable();
				$table->timestamps();
				$table->foreign( 'user_id' )->references( 'ID' )->on( 'users' )->onDelete( 'cascade' );
			}
		);
	}

	/**
	 * Down method.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public static function down() {
		Schema::dropIfExists( 'serviceez_clients' );
	}
}
