<?php
/**
 * Format the service data.
 *
 * @package ServiceEZ\Controllers\Services
 */

namespace ServiceEZ\Controllers\Services;

/**
 * Format the service data.
 *
 * @package ServiceEZ\Controllers\Services
 */
class Format {

	/**
	 * Format the service data.
	 *
	 * @param array $service_data The service data.
	 * @return array The formatted service data.
	 */
	public static function service_data( $service_data ) {
		$service_data['packages'] = array_map(
			function ( $packages ) {
				$packages = array_map(
					function ( $package ) {

						$price         = new Price();
						$package_title = $package['service_title'] . ' - ' . $package['service_name'] . ' - ' . $package['name'];
						$price_data    = array(
							'product_data' => array( 'name' => $package_title ),
							'currency'     => 'usd',
							'unit_amount'  => (int) $package['price'] * 100,
							'metadata'     => array(
								'vendor'       => 'ServiceEZ',
								'service_id'   => $package['service_id'],
								'service_type' => $package['service_type'],
							),
						);

						if ( 'recurring' === $package['pricingType'] ) {
							$price_data['recurring'] = array(
								'interval' => $package['pricingInterval'],
							);
						}
						$vendor_price = $price->create( $price_data );
						if ( $vendor_price ) {
							$package['price_id'] = $vendor_price->id;
						}
						return $package;
					},
					$packages
				);
				return $packages;
			},
			$service_data['packages']
		);

		$service_data['addOns'] = array_map(
			function ( $add_ons ) {
				$add_ons = array_map(
					function ( $add_on ) {

						$price        = new Price();
						$add_on_title = '[ Add-On ] ' . $add_on['service_title'] . ' - ' . $add_on['service_name'] . ' - ' . $add_on['name'];
						$price_data   = array(
							'product_data' => array( 'name' => $add_on_title ),
							'currency'     => 'usd',
							'unit_amount'  => (int) $add_on['price'] * 100,
							'metadata'     => array(
								'vendor'       => 'ServiceEZ',
								'service_id'   => $add_on['service_id'],
								'service_type' => $add_on['service_type'],
							),
						);
						if ( ! empty( $add_on['pricingType'] ) && 'recurring' === $add_on['pricingType'] ) {
							$price_data['recurring'] = array(
								'interval' => $add_on['pricingInterval'],
							);
						}
						$vendor_price = $price->create( $price_data );
						if ( $vendor_price ) {
							$add_on['price_id'] = $vendor_price->id;
						}
						return $add_on;
					},
					$add_ons
				);
				return $add_ons;
			},
			$service_data['addOns']
		);

		return $service_data;
	}
}
