<?php
/**
 * Product class for handling Stripe products.
 *
 * @package ServiceEZ\Controllers\Services
 */

namespace ServiceEZ\Controllers\Services;

/**
 * Product class for handling Stripe products.
 */
class Product {

	/**
	 * @var array
	 */
	private $settings;

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->settings = get_option( 'serviceez_settings' );
	}

	/**
	 * Create a product.
	 *
	 * @param string $product_name The product name.
	 * @return \Stripe\Product|null The created product or null if the key is not set.
	 */
	public function create_product( $product_name ) {
		// If stripe private key is not set, return null.
		if ( empty( $this->settings['payment']['stripeSecretKey'] ) ) {
			return null;
		}

		// Initialize Stripe.
		\Stripe\Stripe::setApiKey( $this->settings['payment']['stripeSecretKey'] );

		try {
			// Create product.
			$product = \Stripe\Product::create( array( 'name' => $product_name ) );

			return $product;
		} catch ( \Stripe\Exception\ApiErrorException $e ) {
			return null;
		}
	}

	/**
	 * Delete a product.
	 *
	 * @param string $product_id The product ID.
	 * @return string|null The result of the deletion or null if the key is not set.
	 */
	public function delete( $product_id ) {
		// If stripe private key is not set, return null.
		if ( empty( $this->settings['payment']['stripeSecretKey'] ) ) {
			return null;
		}

		try {
			$stripe = new \Stripe\StripeClient( $this->settings['payment']['stripeSecretKey'] );

			$stripe->products->delete( $product_id );

			return true;
		} catch ( \Stripe\Exception\ApiErrorException $e ) {
			return false;
		}
	}
}
