<?php
/**
 * Install class.
 *
 * @package ServiceEZ
 * @subpackage Core
 * @since 1.0.0
 */

namespace ServiceEZ\Core;

use ServiceEZ\Database\Migrations\Clients;
use ServiceEZ\Database\Migrations\Coupons;
use ServiceEZ\Database\Migrations\Messages;
use ServiceEZ\Database\Migrations\Orders;
use ServiceEZ\Database\Migrations\Services;
use ServiceEZ\Database\Migrations\Notifications;
use ServiceEZ\Traits\Base;

/**
 * This class is responsible for the functionality
 * which is required to set up after activating the plugin
 */
class Install {


	use Base;

	/**
	 * Initialize the class
	 *
	 * @return void
	 */
	public function init() {
		$this->install_pages();
		$this->install_tables();
		set_transient( 'serviceez_redirect', true, 30 );
	}

	/**
	 * Install the pages
	 *
	 * @return void
	 */
	private function install_pages() {
		serviceez_install_page(
			Template::FRONTEND_TEMPLATE_NAME,
			Template::FRONTEND_TEMPLATE_SLUG,
			Template::FRONTEND_TEMPLATE
		);
	}

	/**
	 * Install the tables
	 *
	 * @return void
	 */
	private function install_tables() {
		Services::up();
		Clients::up();
		Orders::up();
		Coupons::up();
		Notifications::up();
		Messages::up();
	}

	/**
	 * Redirect to the admin page.
	 *
	 * @since 1.0.0
	 * @return void
	 */
	public function serviceez_redirect_after_activation() {
		// Check if the transient is set.
		if ( get_transient( 'serviceez_redirect' ) ) {
			// Delete the transient to prevent multiple redirects.
			delete_transient( 'serviceez_redirect' );

			// Redirect to the desired admin page.
			wp_safe_redirect( admin_url( 'admin.php?page=serviceez' ) );
			exit;
		}
	}
}
