<?php
/**
 * Order model class.
 *
 * @package ServiceEZ
 * @subpackage Models
 * @since 1.0.0
 */

namespace ServiceEZ\Models;

use Prappo\WpEloquent\Database\Eloquent\Model;

/**
 * Order model class.
 *
 * @package ServiceEZ
 * @subpackage Models
 * @since 1.0.0
 */
class Order extends Model {

	/**
	 * Table name.
	 *
	 * @var string
	 */
	protected $table = 'serviceez_orders';

	/**
	 * Fillable fields.
	 *
	 * @var array
	 */
	protected $fillable = array(
		'client_id',
		'service_id',
		'payment_status',
		'payment_method',
		'order_status',
		'total_amount',
		'data',
	);

	/**
	 * Casts.
	 *
	 * @var array
	 */
	protected $casts = array(
		'data' => 'array',
	);

	/**
	 * Client relationship.
	 *
	 * @return \Prappo\WpEloquent\Database\Eloquent\Relations\BelongsTo
	 */
	public function client() {
		return $this->belongsTo( Client::class );
	}

	/**
	 * Service relationship.
	 *
	 * @return \Prappo\WpEloquent\Database\Eloquent\Relations\BelongsTo
	 */
	public function service() {
		return $this->belongsTo( Service::class );
	}
}
